@@ -6,36 +6,16 @@ from pulsar import to_bytes, is_failure, log_failure, is_async,\
                     as_failure, maybe_async, HttpException
 from pulsar.utils.tools import checkarity
 from pulsar.utils.structures import AttributeDictionary
-from pulsar.apps.wsgi import WsgiResponse, WsgiResponseGenerator
+from pulsar.apps.wsgi import WsgiResponse, WsgiResponseGenerator, Request
 
 from .decorators import rpcerror, wrap_object_call
 from .exceptions import *
 
 
-__all__ = ['RpcHandler', 'RpcMiddleware']
+__all__ = ['RpcMiddleware']
 
 LOGGER = logging.getLogger('pulsar.rpc')
 
-
-class RpcRequest:
-
-    def __init__(self, environ):
-        self.environ = environ
-
-    def __repr__(self):
-        return self.rpc.method
-    __str__ = __repr__
-
-    def __getattr__(self, name):
-        return self.environ.get(name)
-
-    def __getitem__(self, name):
-        return self.environ[name]
-    
-    def __setitem__(self, name, value):
-        self.environ[name] = value
-
-
 class RPC:
     
     def __init__(self, handler, method, func, args, kwargs,
@@ -152,6 +132,7 @@ class RpcHandler(MetaRpcHandler('_RpcHandler', (object,), {'virtual': True})):
     separator    = '.'
     '''Separator between :attr:`subHandlers`.'''
     content_type = 'text/plain'
+    methods = ('get','post','put','head','delete','trace','connect')
     charset = 'utf-8'
     _info_exceptions = (Fault,)
 
@@ -278,13 +259,11 @@ class RpcMiddleware(object):
 
     Default ``None``
 '''
-    methods = ('get','post','put','head','delete','trace','connect')
-    request_class = RpcRequest
+    request_class = Request
 
-    def __init__(self, handler, path=None, methods=None):
+    def __init__(self, handler, path=None):
         self.handler = handler
         self.path = path or '/'
-        self.methods = methods or self.methods
 
     def __str__(self):
         return self.path
@@ -301,8 +280,9 @@ class RpcMiddleware(object):
         path = environ['PATH_INFO'] or '/'
         if path == self.path:
             method = environ['REQUEST_METHOD'].lower()
-            if method not in self.methods:
-                raise HttpException(status=405)
+            if method not in self.handler.methods:
+                raise HttpException(status=405, msg='Method "%s" not allowed' %\
+                                    method)
             data = environ['wsgi.input'].read()
             hnd = self.handler
             method, args, kwargs, id, version = hnd.get_method_and_args(data)
