@@ -1,3 +1,5 @@
+from time import time
+
 from pulsar import AuthenticationError
 from . import proxy 
 
@@ -60,8 +62,6 @@ def config(client, actor, setget, name, *value):
 @proxy.command(internal=True)
 def mailbox_address(client, actor, caller, address):
     '''The remote *caller* register its mailbox ``address``.'''
-    if address:
-        actor.logger.debug('Registering %s inbox address %s', caller, address)
     actor.link_actor(caller, address)
     return actor.proxy
 
@@ -78,7 +78,9 @@ def stop(client, actor, caller):
 @proxy.command(ack=False, internal=True)
 def notify(client, actor, caller, info):
     '''caller notify itself.'''
-    caller.info = info
+    if isinstance(info, dict):
+        info['last_notified'] = time()
+        caller.info = info
     
 ###########################################################  ARBITER COMMANDS
 @proxy.command(internal=True, commands_set=proxy.arbiter_commands)
@@ -88,12 +90,15 @@ def spawn(client, actor, caller, linked_actors=None, **kwargs):
     return actor.spawn(linked_actors=linked_actors, **kwargs)
      
 @proxy.command(authenticated=True, commands_set=proxy.arbiter_commands)
-def kill_actor(client, actor, aid):
+def kill_actor(client, actor, aid=None):
     '''Kill an actor with id ``aid``'''
-    a = actor.get_actor(aid)
-    if a:
-        a.stop()
-        return 'stopped %s' % a
+    if not aid:
+        return actor.stop()
     else:
-        actor.logger.info('Could not kill "%s" no such actor', aid)
+        a = actor.get_actor(aid)
+        if a:
+            a.stop()
+            return 'stopped %s' % a
+        else:
+            actor.logger.info('Could not kill "%s" no such actor', aid)
         
\ No newline at end of file
