@@ -17,7 +17,8 @@ __all__ = ['IOpoll',
            'daemonize',
            'SIGQUIT',
            'get_uid',
-           'get_gid']
+           'get_gid',
+           'get_maxfd']
 
 # See: http://msdn.microsoft.com/en-us/library/ms724935(VS.85).aspx
 SetHandleInformation = ctypes.windll.kernel32.SetHandleInformation
@@ -60,9 +61,15 @@ def get_gid(group=None):
 def setpgrp():
     pass
 
+def get_maxfd():
+    return MAXFD
+
+def daemonize():
+    pass
+
 
 class IOpoll(IOselect):
-    
+    '''The default windows IO poll class. Based on select.'''
     def poll(self, timeout=None):
         """Win32 select wrapper."""
         if not (self.read_fds or self.write_fds):
@@ -77,11 +84,11 @@ class IOpoll(IOselect):
         # time or ctrl-c will never be recognized
         if timeout is None or timeout > 0.5:
             timeout = 0.5
-        return super(IOpoll,self).poll(timeout)
+        return super(IOpoll, self).poll(timeout)
     
     
 class Waker(object):
-    '''In windows '''
+    '''In windows'''
     def __init__(self):
         self._writer, s = socket_pair(backlog = 1)
         s.setblocking(True)   
@@ -114,6 +121,3 @@ class Waker(object):
         self.reader.close()
         self.writer.close()
         
-    
-def daemonize():
-    pass
